# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.models.pdf_form_fields import PdfFormFields  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestPdfFormFields(unittest.TestCase):
    """PdfFormFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPdfFormFields(self):
        """Test PdfFormFields"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_convert_api_client.models.pdf_form_fields.PdfFormFields()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_convert_api_client.api_client import ApiClient


class ConvertTemplateApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def convert_template_apply_docx_template(self, input_file, **kwargs):  # noqa: E501
        """Apply Word DOCX template  # noqa: E501

        Apply operations to fill in a Word DOCX template by replacing target template/placeholder strings in the DOCX with values, generating a final Word DOCX result.  For example, you could create a Word Document invoice containing strings such as \"{FirstName}\" and \"{LastName}\" and then replace these values with \"John\" and \"Smith\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_template_apply_docx_template(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param object template_definition: Template definition for the document, including what values to replace
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_template_apply_docx_template_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_template_apply_docx_template_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def convert_template_apply_docx_template_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Apply Word DOCX template  # noqa: E501

        Apply operations to fill in a Word DOCX template by replacing target template/placeholder strings in the DOCX with values, generating a final Word DOCX result.  For example, you could create a Word Document invoice containing strings such as \"{FirstName}\" and \"{LastName}\" and then replace these values with \"John\" and \"Smith\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_template_apply_docx_template_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param object template_definition: Template definition for the document, including what values to replace
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'template_definition']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_template_apply_docx_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `convert_template_apply_docx_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'template_definition' in params:
            header_params['templateDefinition'] = params['template_definition']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/template/docx/apply', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def convert_template_apply_html_template(self, value, **kwargs):  # noqa: E501
        """Apply HTML template  # noqa: E501

        Apply operations to fill in an HTML template, generating a final HTML result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_template_apply_html_template(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HtmlTemplateApplicationRequest value: Operations to apply to template (required)
        :return: HtmlTemplateApplicationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_template_apply_html_template_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_template_apply_html_template_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def convert_template_apply_html_template_with_http_info(self, value, **kwargs):  # noqa: E501
        """Apply HTML template  # noqa: E501

        Apply operations to fill in an HTML template, generating a final HTML result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_template_apply_html_template_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HtmlTemplateApplicationRequest value: Operations to apply to template (required)
        :return: HtmlTemplateApplicationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_template_apply_html_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `convert_template_apply_html_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/template/html/apply', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HtmlTemplateApplicationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HtmlTemplateOperation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action': 'int',
        'match_agsint': 'str',
        'replace_with': 'str'
    }

    attribute_map = {
        'action': 'Action',
        'match_agsint': 'MatchAgsint',
        'replace_with': 'ReplaceWith'
    }

    def __init__(self, action=None, match_agsint=None, replace_with=None):  # noqa: E501
        """HtmlTemplateOperation - a model defined in Swagger"""  # noqa: E501

        self._action = None
        self._match_agsint = None
        self._replace_with = None
        self.discriminator = None

        if action is not None:
            self.action = action
        if match_agsint is not None:
            self.match_agsint = match_agsint
        if replace_with is not None:
            self.replace_with = replace_with

    @property
    def action(self):
        """Gets the action of this HtmlTemplateOperation.  # noqa: E501

        Operation action to take; possible values are \"Replace\"  # noqa: E501

        :return: The action of this HtmlTemplateOperation.  # noqa: E501
        :rtype: int
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this HtmlTemplateOperation.

        Operation action to take; possible values are \"Replace\"  # noqa: E501

        :param action: The action of this HtmlTemplateOperation.  # noqa: E501
        :type: int
        """
        allowed_values = [1]  # noqa: E501
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def match_agsint(self):
        """Gets the match_agsint of this HtmlTemplateOperation.  # noqa: E501

        For Replace operations, the string to match against (to be replaced with ReplaceWith string)  # noqa: E501

        :return: The match_agsint of this HtmlTemplateOperation.  # noqa: E501
        :rtype: str
        """
        return self._match_agsint

    @match_agsint.setter
    def match_agsint(self, match_agsint):
        """Sets the match_agsint of this HtmlTemplateOperation.

        For Replace operations, the string to match against (to be replaced with ReplaceWith string)  # noqa: E501

        :param match_agsint: The match_agsint of this HtmlTemplateOperation.  # noqa: E501
        :type: str
        """

        self._match_agsint = match_agsint

    @property
    def replace_with(self):
        """Gets the replace_with of this HtmlTemplateOperation.  # noqa: E501

        For Replace operations, the string to Replace the original string with  # noqa: E501

        :return: The replace_with of this HtmlTemplateOperation.  # noqa: E501
        :rtype: str
        """
        return self._replace_with

    @replace_with.setter
    def replace_with(self, replace_with):
        """Sets the replace_with of this HtmlTemplateOperation.

        For Replace operations, the string to Replace the original string with  # noqa: E501

        :param replace_with: The replace_with of this HtmlTemplateOperation.  # noqa: E501
        :type: str
        """

        self._replace_with = replace_with

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HtmlTemplateOperation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HtmlTemplateOperation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AutodetectDocumentValidationResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_format_extension': 'str',
        'document_is_valid': 'bool',
        'error_count': 'int',
        'warning_count': 'int',
        'errors_and_warnings': 'list[DocumentValidationError]'
    }

    attribute_map = {
        'file_format_extension': 'FileFormatExtension',
        'document_is_valid': 'DocumentIsValid',
        'error_count': 'ErrorCount',
        'warning_count': 'WarningCount',
        'errors_and_warnings': 'ErrorsAndWarnings'
    }

    def __init__(self, file_format_extension=None, document_is_valid=None, error_count=None, warning_count=None, errors_and_warnings=None):  # noqa: E501
        """AutodetectDocumentValidationResult - a model defined in Swagger"""  # noqa: E501

        self._file_format_extension = None
        self._document_is_valid = None
        self._error_count = None
        self._warning_count = None
        self._errors_and_warnings = None
        self.discriminator = None

        if file_format_extension is not None:
            self.file_format_extension = file_format_extension
        if document_is_valid is not None:
            self.document_is_valid = document_is_valid
        if error_count is not None:
            self.error_count = error_count
        if warning_count is not None:
            self.warning_count = warning_count
        if errors_and_warnings is not None:
            self.errors_and_warnings = errors_and_warnings

    @property
    def file_format_extension(self):
        """Gets the file_format_extension of this AutodetectDocumentValidationResult.  # noqa: E501


        :return: The file_format_extension of this AutodetectDocumentValidationResult.  # noqa: E501
        :rtype: str
        """
        return self._file_format_extension

    @file_format_extension.setter
    def file_format_extension(self, file_format_extension):
        """Sets the file_format_extension of this AutodetectDocumentValidationResult.


        :param file_format_extension: The file_format_extension of this AutodetectDocumentValidationResult.  # noqa: E501
        :type: str
        """

        self._file_format_extension = file_format_extension

    @property
    def document_is_valid(self):
        """Gets the document_is_valid of this AutodetectDocumentValidationResult.  # noqa: E501

        True if the document is valid and has no errors, false otherwise  # noqa: E501

        :return: The document_is_valid of this AutodetectDocumentValidationResult.  # noqa: E501
        :rtype: bool
        """
        return self._document_is_valid

    @document_is_valid.setter
    def document_is_valid(self, document_is_valid):
        """Sets the document_is_valid of this AutodetectDocumentValidationResult.

        True if the document is valid and has no errors, false otherwise  # noqa: E501

        :param document_is_valid: The document_is_valid of this AutodetectDocumentValidationResult.  # noqa: E501
        :type: bool
        """

        self._document_is_valid = document_is_valid

    @property
    def error_count(self):
        """Gets the error_count of this AutodetectDocumentValidationResult.  # noqa: E501

        Number of validation errors found in the document  # noqa: E501

        :return: The error_count of this AutodetectDocumentValidationResult.  # noqa: E501
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this AutodetectDocumentValidationResult.

        Number of validation errors found in the document  # noqa: E501

        :param error_count: The error_count of this AutodetectDocumentValidationResult.  # noqa: E501
        :type: int
        """

        self._error_count = error_count

    @property
    def warning_count(self):
        """Gets the warning_count of this AutodetectDocumentValidationResult.  # noqa: E501

        Number of validation warnings found in the document  # noqa: E501

        :return: The warning_count of this AutodetectDocumentValidationResult.  # noqa: E501
        :rtype: int
        """
        return self._warning_count

    @warning_count.setter
    def warning_count(self, warning_count):
        """Sets the warning_count of this AutodetectDocumentValidationResult.

        Number of validation warnings found in the document  # noqa: E501

        :param warning_count: The warning_count of this AutodetectDocumentValidationResult.  # noqa: E501
        :type: int
        """

        self._warning_count = warning_count

    @property
    def errors_and_warnings(self):
        """Gets the errors_and_warnings of this AutodetectDocumentValidationResult.  # noqa: E501

        Details of errors and warnings found  # noqa: E501

        :return: The errors_and_warnings of this AutodetectDocumentValidationResult.  # noqa: E501
        :rtype: list[DocumentValidationError]
        """
        return self._errors_and_warnings

    @errors_and_warnings.setter
    def errors_and_warnings(self, errors_and_warnings):
        """Sets the errors_and_warnings of this AutodetectDocumentValidationResult.

        Details of errors and warnings found  # noqa: E501

        :param errors_and_warnings: The errors_and_warnings of this AutodetectDocumentValidationResult.  # noqa: E501
        :type: list[DocumentValidationError]
        """

        self._errors_and_warnings = errors_and_warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AutodetectDocumentValidationResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutodetectDocumentValidationResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxInsertCommentOnParagraphRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_file_bytes': 'str',
        'input_file_url': 'str',
        'paragraph_path': 'str',
        'comment_to_insert': 'DocxComment'
    }

    attribute_map = {
        'input_file_bytes': 'InputFileBytes',
        'input_file_url': 'InputFileUrl',
        'paragraph_path': 'ParagraphPath',
        'comment_to_insert': 'CommentToInsert'
    }

    def __init__(self, input_file_bytes=None, input_file_url=None, paragraph_path=None, comment_to_insert=None):  # noqa: E501
        """DocxInsertCommentOnParagraphRequest - a model defined in Swagger"""  # noqa: E501

        self._input_file_bytes = None
        self._input_file_url = None
        self._paragraph_path = None
        self._comment_to_insert = None
        self.discriminator = None

        if input_file_bytes is not None:
            self.input_file_bytes = input_file_bytes
        if input_file_url is not None:
            self.input_file_url = input_file_url
        if paragraph_path is not None:
            self.paragraph_path = paragraph_path
        if comment_to_insert is not None:
            self.comment_to_insert = comment_to_insert

    @property
    def input_file_bytes(self):
        """Gets the input_file_bytes of this DocxInsertCommentOnParagraphRequest.  # noqa: E501

        Optional: Bytes of the input file to operate on  # noqa: E501

        :return: The input_file_bytes of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_file_bytes

    @input_file_bytes.setter
    def input_file_bytes(self, input_file_bytes):
        """Sets the input_file_bytes of this DocxInsertCommentOnParagraphRequest.

        Optional: Bytes of the input file to operate on  # noqa: E501

        :param input_file_bytes: The input_file_bytes of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :type: str
        """
        if input_file_bytes is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', input_file_bytes):  # noqa: E501
            raise ValueError(r"Invalid value for `input_file_bytes`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._input_file_bytes = input_file_bytes

    @property
    def input_file_url(self):
        """Gets the input_file_url of this DocxInsertCommentOnParagraphRequest.  # noqa: E501

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :return: The input_file_url of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_file_url

    @input_file_url.setter
    def input_file_url(self, input_file_url):
        """Sets the input_file_url of this DocxInsertCommentOnParagraphRequest.

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :param input_file_url: The input_file_url of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :type: str
        """

        self._input_file_url = input_file_url

    @property
    def paragraph_path(self):
        """Gets the paragraph_path of this DocxInsertCommentOnParagraphRequest.  # noqa: E501

        Path to the paragraph to attach the comment to.  You can get the Path by retrieving all of the Paragraphs in document by calling Get Body and taking the Path property of the desired paragraph to add the comment to.  # noqa: E501

        :return: The paragraph_path of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :rtype: str
        """
        return self._paragraph_path

    @paragraph_path.setter
    def paragraph_path(self, paragraph_path):
        """Sets the paragraph_path of this DocxInsertCommentOnParagraphRequest.

        Path to the paragraph to attach the comment to.  You can get the Path by retrieving all of the Paragraphs in document by calling Get Body and taking the Path property of the desired paragraph to add the comment to.  # noqa: E501

        :param paragraph_path: The paragraph_path of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :type: str
        """

        self._paragraph_path = paragraph_path

    @property
    def comment_to_insert(self):
        """Gets the comment_to_insert of this DocxInsertCommentOnParagraphRequest.  # noqa: E501

        Comment to insert  # noqa: E501

        :return: The comment_to_insert of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :rtype: DocxComment
        """
        return self._comment_to_insert

    @comment_to_insert.setter
    def comment_to_insert(self, comment_to_insert):
        """Sets the comment_to_insert of this DocxInsertCommentOnParagraphRequest.

        Comment to insert  # noqa: E501

        :param comment_to_insert: The comment_to_insert of this DocxInsertCommentOnParagraphRequest.  # noqa: E501
        :type: DocxComment
        """

        self._comment_to_insert = comment_to_insert

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxInsertCommentOnParagraphRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxInsertCommentOnParagraphRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PdfAnnotation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'annotation_type': 'str',
        'page_number': 'int',
        'annotation_index': 'int',
        'subject': 'str',
        'text_contents': 'str',
        'creation_date': 'datetime',
        'modified_date': 'datetime',
        'left_x': 'float',
        'top_y': 'float',
        'width': 'float',
        'height': 'float'
    }

    attribute_map = {
        'title': 'Title',
        'annotation_type': 'AnnotationType',
        'page_number': 'PageNumber',
        'annotation_index': 'AnnotationIndex',
        'subject': 'Subject',
        'text_contents': 'TextContents',
        'creation_date': 'CreationDate',
        'modified_date': 'ModifiedDate',
        'left_x': 'LeftX',
        'top_y': 'TopY',
        'width': 'Width',
        'height': 'Height'
    }

    def __init__(self, title=None, annotation_type=None, page_number=None, annotation_index=None, subject=None, text_contents=None, creation_date=None, modified_date=None, left_x=None, top_y=None, width=None, height=None):  # noqa: E501
        """PdfAnnotation - a model defined in Swagger"""  # noqa: E501

        self._title = None
        self._annotation_type = None
        self._page_number = None
        self._annotation_index = None
        self._subject = None
        self._text_contents = None
        self._creation_date = None
        self._modified_date = None
        self._left_x = None
        self._top_y = None
        self._width = None
        self._height = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if annotation_type is not None:
            self.annotation_type = annotation_type
        if page_number is not None:
            self.page_number = page_number
        if annotation_index is not None:
            self.annotation_index = annotation_index
        if subject is not None:
            self.subject = subject
        if text_contents is not None:
            self.text_contents = text_contents
        if creation_date is not None:
            self.creation_date = creation_date
        if modified_date is not None:
            self.modified_date = modified_date
        if left_x is not None:
            self.left_x = left_x
        if top_y is not None:
            self.top_y = top_y
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height

    @property
    def title(self):
        """Gets the title of this PdfAnnotation.  # noqa: E501

        Title of the annotation; this is often the author of the annotation in Acrobat-created PDF files  # noqa: E501

        :return: The title of this PdfAnnotation.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PdfAnnotation.

        Title of the annotation; this is often the author of the annotation in Acrobat-created PDF files  # noqa: E501

        :param title: The title of this PdfAnnotation.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def annotation_type(self):
        """Gets the annotation_type of this PdfAnnotation.  # noqa: E501

        Type of the annotation; possible values are Text  # noqa: E501

        :return: The annotation_type of this PdfAnnotation.  # noqa: E501
        :rtype: str
        """
        return self._annotation_type

    @annotation_type.setter
    def annotation_type(self, annotation_type):
        """Sets the annotation_type of this PdfAnnotation.

        Type of the annotation; possible values are Text  # noqa: E501

        :param annotation_type: The annotation_type of this PdfAnnotation.  # noqa: E501
        :type: str
        """

        self._annotation_type = annotation_type

    @property
    def page_number(self):
        """Gets the page_number of this PdfAnnotation.  # noqa: E501

        The 1-based index of the page containing the annotation  # noqa: E501

        :return: The page_number of this PdfAnnotation.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this PdfAnnotation.

        The 1-based index of the page containing the annotation  # noqa: E501

        :param page_number: The page_number of this PdfAnnotation.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def annotation_index(self):
        """Gets the annotation_index of this PdfAnnotation.  # noqa: E501

        The 0-based index of the annotation in the document  # noqa: E501

        :return: The annotation_index of this PdfAnnotation.  # noqa: E501
        :rtype: int
        """
        return self._annotation_index

    @annotation_index.setter
    def annotation_index(self, annotation_index):
        """Sets the annotation_index of this PdfAnnotation.

        The 0-based index of the annotation in the document  # noqa: E501

        :param annotation_index: The annotation_index of this PdfAnnotation.  # noqa: E501
        :type: int
        """

        self._annotation_index = annotation_index

    @property
    def subject(self):
        """Gets the subject of this PdfAnnotation.  # noqa: E501

        Subject of the annotation  # noqa: E501

        :return: The subject of this PdfAnnotation.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this PdfAnnotation.

        Subject of the annotation  # noqa: E501

        :param subject: The subject of this PdfAnnotation.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def text_contents(self):
        """Gets the text_contents of this PdfAnnotation.  # noqa: E501

        Text contents of the annotation  # noqa: E501

        :return: The text_contents of this PdfAnnotation.  # noqa: E501
        :rtype: str
        """
        return self._text_contents

    @text_contents.setter
    def text_contents(self, text_contents):
        """Sets the text_contents of this PdfAnnotation.

        Text contents of the annotation  # noqa: E501

        :param text_contents: The text_contents of this PdfAnnotation.  # noqa: E501
        :type: str
        """

        self._text_contents = text_contents

    @property
    def creation_date(self):
        """Gets the creation_date of this PdfAnnotation.  # noqa: E501

        Date that the annotation was created  # noqa: E501

        :return: The creation_date of this PdfAnnotation.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this PdfAnnotation.

        Date that the annotation was created  # noqa: E501

        :param creation_date: The creation_date of this PdfAnnotation.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def modified_date(self):
        """Gets the modified_date of this PdfAnnotation.  # noqa: E501

        Date that the annotation was last modified  # noqa: E501

        :return: The modified_date of this PdfAnnotation.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """Sets the modified_date of this PdfAnnotation.

        Date that the annotation was last modified  # noqa: E501

        :param modified_date: The modified_date of this PdfAnnotation.  # noqa: E501
        :type: datetime
        """

        self._modified_date = modified_date

    @property
    def left_x(self):
        """Gets the left_x of this PdfAnnotation.  # noqa: E501

        Left X coordinate for the location of the annotation  # noqa: E501

        :return: The left_x of this PdfAnnotation.  # noqa: E501
        :rtype: float
        """
        return self._left_x

    @left_x.setter
    def left_x(self, left_x):
        """Sets the left_x of this PdfAnnotation.

        Left X coordinate for the location of the annotation  # noqa: E501

        :param left_x: The left_x of this PdfAnnotation.  # noqa: E501
        :type: float
        """

        self._left_x = left_x

    @property
    def top_y(self):
        """Gets the top_y of this PdfAnnotation.  # noqa: E501

        Top Y coordination of the location of the annotation  # noqa: E501

        :return: The top_y of this PdfAnnotation.  # noqa: E501
        :rtype: float
        """
        return self._top_y

    @top_y.setter
    def top_y(self, top_y):
        """Sets the top_y of this PdfAnnotation.

        Top Y coordination of the location of the annotation  # noqa: E501

        :param top_y: The top_y of this PdfAnnotation.  # noqa: E501
        :type: float
        """

        self._top_y = top_y

    @property
    def width(self):
        """Gets the width of this PdfAnnotation.  # noqa: E501

        Width of the annotation  # noqa: E501

        :return: The width of this PdfAnnotation.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this PdfAnnotation.

        Width of the annotation  # noqa: E501

        :param width: The width of this PdfAnnotation.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this PdfAnnotation.  # noqa: E501

        Height of the annotation  # noqa: E501

        :return: The height of this PdfAnnotation.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this PdfAnnotation.

        Height of the annotation  # noqa: E501

        :param height: The height of this PdfAnnotation.  # noqa: E501
        :type: float
        """

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfAnnotation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfAnnotation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cloudmersive_convert_api_client.api.compare_document_api import CompareDocumentApi
from cloudmersive_convert_api_client.api.convert_data_api import ConvertDataApi
from cloudmersive_convert_api_client.api.convert_document_api import ConvertDocumentApi
from cloudmersive_convert_api_client.api.convert_image_api import ConvertImageApi
from cloudmersive_convert_api_client.api.convert_template_api import ConvertTemplateApi
from cloudmersive_convert_api_client.api.convert_web_api import ConvertWebApi
from cloudmersive_convert_api_client.api.edit_document_api import EditDocumentApi
from cloudmersive_convert_api_client.api.edit_pdf_api import EditPdfApi
from cloudmersive_convert_api_client.api.edit_text_api import EditTextApi
from cloudmersive_convert_api_client.api.merge_document_api import MergeDocumentApi
from cloudmersive_convert_api_client.api.split_document_api import SplitDocumentApi
from cloudmersive_convert_api_client.api.validate_document_api import ValidateDocumentApi
from cloudmersive_convert_api_client.api.viewer_tools_api import ViewerToolsApi
from cloudmersive_convert_api_client.api.zip_archive_api import ZipArchiveApi



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_convert_api_client.api_client import ApiClient


class ZipArchiveApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def zip_archive_zip_create(self, input_file1, **kwargs):  # noqa: E501
        """Compress files to create a new zip archive  # noqa: E501

        Create a new zip archive by compressing input files.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_create(input_file1, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file1: First input file to perform the operation on. (required)
        :param file input_file2: Second input file to perform the operation on.
        :param file input_file3: Third input file to perform the operation on.
        :param file input_file4: Fourth input file to perform the operation on.
        :param file input_file5: Fifth input file to perform the operation on.
        :param file input_file6: Sixth input file to perform the operation on.
        :param file input_file7: Seventh input file to perform the operation on.
        :param file input_file8: Eighth input file to perform the operation on.
        :param file input_file9: Ninth input file to perform the operation on.
        :param file input_file10: Tenth input file to perform the operation on.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zip_archive_zip_create_with_http_info(input_file1, **kwargs)  # noqa: E501
        else:
            (data) = self.zip_archive_zip_create_with_http_info(input_file1, **kwargs)  # noqa: E501
            return data

    def zip_archive_zip_create_with_http_info(self, input_file1, **kwargs):  # noqa: E501
        """Compress files to create a new zip archive  # noqa: E501

        Create a new zip archive by compressing input files.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_create_with_http_info(input_file1, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file1: First input file to perform the operation on. (required)
        :param file input_file2: Second input file to perform the operation on.
        :param file input_file3: Third input file to perform the operation on.
        :param file input_file4: Fourth input file to perform the operation on.
        :param file input_file5: Fifth input file to perform the operation on.
        :param file input_file6: Sixth input file to perform the operation on.
        :param file input_file7: Seventh input file to perform the operation on.
        :param file input_file8: Eighth input file to perform the operation on.
        :param file input_file9: Ninth input file to perform the operation on.
        :param file input_file10: Tenth input file to perform the operation on.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file1', 'input_file2', 'input_file3', 'input_file4', 'input_file5', 'input_file6', 'input_file7', 'input_file8', 'input_file9', 'input_file10']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zip_archive_zip_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file1' is set
        if ('input_file1' not in params or
                params['input_file1'] is None):
            raise ValueError("Missing the required parameter `input_file1` when calling `zip_archive_zip_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file1' in params:
            local_var_files['inputFile1'] = params['input_file1']  # noqa: E501
        if 'input_file2' in params:
            local_var_files['inputFile2'] = params['input_file2']  # noqa: E501
        if 'input_file3' in params:
            local_var_files['inputFile3'] = params['input_file3']  # noqa: E501
        if 'input_file4' in params:
            local_var_files['inputFile4'] = params['input_file4']  # noqa: E501
        if 'input_file5' in params:
            local_var_files['inputFile5'] = params['input_file5']  # noqa: E501
        if 'input_file6' in params:
            local_var_files['inputFile6'] = params['input_file6']  # noqa: E501
        if 'input_file7' in params:
            local_var_files['inputFile7'] = params['input_file7']  # noqa: E501
        if 'input_file8' in params:
            local_var_files['inputFile8'] = params['input_file8']  # noqa: E501
        if 'input_file9' in params:
            local_var_files['inputFile9'] = params['input_file9']  # noqa: E501
        if 'input_file10' in params:
            local_var_files['inputFile10'] = params['input_file10']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/archive/zip/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def zip_archive_zip_create_advanced(self, request, **kwargs):  # noqa: E501
        """Compress files and folders to create a new zip archive with advanced options  # noqa: E501

        Create a new zip archive by compressing input files, folders and leverage advanced options to control the structure of the resulting zip archive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_create_advanced(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateZipArchiveRequest request: Input request (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zip_archive_zip_create_advanced_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.zip_archive_zip_create_advanced_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def zip_archive_zip_create_advanced_with_http_info(self, request, **kwargs):  # noqa: E501
        """Compress files and folders to create a new zip archive with advanced options  # noqa: E501

        Create a new zip archive by compressing input files, folders and leverage advanced options to control the structure of the resulting zip archive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_create_advanced_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateZipArchiveRequest request: Input request (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zip_archive_zip_create_advanced" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `zip_archive_zip_create_advanced`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/archive/zip/create/advanced', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def zip_archive_zip_decrypt(self, input_file, zip_password, **kwargs):  # noqa: E501
        """Decrypt and remove password protection on a zip file  # noqa: E501

        Decrypts and removes password protection from an encrypted zip file with the specified password  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_decrypt(input_file, zip_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str zip_password: Required; Password for the input archive (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zip_archive_zip_decrypt_with_http_info(input_file, zip_password, **kwargs)  # noqa: E501
        else:
            (data) = self.zip_archive_zip_decrypt_with_http_info(input_file, zip_password, **kwargs)  # noqa: E501
            return data

    def zip_archive_zip_decrypt_with_http_info(self, input_file, zip_password, **kwargs):  # noqa: E501
        """Decrypt and remove password protection on a zip file  # noqa: E501

        Decrypts and removes password protection from an encrypted zip file with the specified password  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_decrypt_with_http_info(input_file, zip_password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str zip_password: Required; Password for the input archive (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'zip_password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zip_archive_zip_decrypt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `zip_archive_zip_decrypt`")  # noqa: E501
        # verify the required parameter 'zip_password' is set
        if ('zip_password' not in params or
                params['zip_password'] is None):
            raise ValueError("Missing the required parameter `zip_password` when calling `zip_archive_zip_decrypt`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'zip_password' in params:
            header_params['zipPassword'] = params['zip_password']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/archive/zip/decrypt', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def zip_archive_zip_encrypt_advanced(self, encryption_request, **kwargs):  # noqa: E501
        """Encrypt and password protect a zip file  # noqa: E501

        Encrypts and password protects an existing zip file with the specified password and encryption algorithm  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_encrypt_advanced(encryption_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ZipEncryptionAdvancedRequest encryption_request: Encryption request (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zip_archive_zip_encrypt_advanced_with_http_info(encryption_request, **kwargs)  # noqa: E501
        else:
            (data) = self.zip_archive_zip_encrypt_advanced_with_http_info(encryption_request, **kwargs)  # noqa: E501
            return data

    def zip_archive_zip_encrypt_advanced_with_http_info(self, encryption_request, **kwargs):  # noqa: E501
        """Encrypt and password protect a zip file  # noqa: E501

        Encrypts and password protects an existing zip file with the specified password and encryption algorithm  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_encrypt_advanced_with_http_info(encryption_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ZipEncryptionAdvancedRequest encryption_request: Encryption request (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['encryption_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zip_archive_zip_encrypt_advanced" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'encryption_request' is set
        if ('encryption_request' not in params or
                params['encryption_request'] is None):
            raise ValueError("Missing the required parameter `encryption_request` when calling `zip_archive_zip_encrypt_advanced`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'encryption_request' in params:
            body_params = params['encryption_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/archive/zip/encrypt/advanced', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def zip_archive_zip_extract(self, input_file, **kwargs):  # noqa: E501
        """Extract, decompress files and folders from a zip archive  # noqa: E501

        Extracts a zip archive by decompressing files, and folders.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_extract(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: ZipExtractResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zip_archive_zip_extract_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.zip_archive_zip_extract_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def zip_archive_zip_extract_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Extract, decompress files and folders from a zip archive  # noqa: E501

        Extracts a zip archive by decompressing files, and folders.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zip_archive_zip_extract_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: ZipExtractResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zip_archive_zip_extract" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `zip_archive_zip_extract`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/archive/zip/extract', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ZipExtractResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxImage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'image_name': 'str',
        'image_id': 'int',
        'image_description': 'str',
        'image_width': 'int',
        'image_height': 'int',
        'x_offset': 'int',
        'y_offset': 'int',
        'image_data_embed_id': 'str',
        'image_data_content_type': 'str',
        'image_internal_file_name': 'str',
        'image_contents_url': 'str',
        'inline_with_text': 'bool'
    }

    attribute_map = {
        'path': 'Path',
        'image_name': 'ImageName',
        'image_id': 'ImageId',
        'image_description': 'ImageDescription',
        'image_width': 'ImageWidth',
        'image_height': 'ImageHeight',
        'x_offset': 'XOffset',
        'y_offset': 'YOffset',
        'image_data_embed_id': 'ImageDataEmbedId',
        'image_data_content_type': 'ImageDataContentType',
        'image_internal_file_name': 'ImageInternalFileName',
        'image_contents_url': 'ImageContentsURL',
        'inline_with_text': 'InlineWithText'
    }

    def __init__(self, path=None, image_name=None, image_id=None, image_description=None, image_width=None, image_height=None, x_offset=None, y_offset=None, image_data_embed_id=None, image_data_content_type=None, image_internal_file_name=None, image_contents_url=None, inline_with_text=None):  # noqa: E501
        """DocxImage - a model defined in Swagger"""  # noqa: E501

        self._path = None
        self._image_name = None
        self._image_id = None
        self._image_description = None
        self._image_width = None
        self._image_height = None
        self._x_offset = None
        self._y_offset = None
        self._image_data_embed_id = None
        self._image_data_content_type = None
        self._image_internal_file_name = None
        self._image_contents_url = None
        self._inline_with_text = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if image_name is not None:
            self.image_name = image_name
        if image_id is not None:
            self.image_id = image_id
        if image_description is not None:
            self.image_description = image_description
        if image_width is not None:
            self.image_width = image_width
        if image_height is not None:
            self.image_height = image_height
        if x_offset is not None:
            self.x_offset = x_offset
        if y_offset is not None:
            self.y_offset = y_offset
        if image_data_embed_id is not None:
            self.image_data_embed_id = image_data_embed_id
        if image_data_content_type is not None:
            self.image_data_content_type = image_data_content_type
        if image_internal_file_name is not None:
            self.image_internal_file_name = image_internal_file_name
        if image_contents_url is not None:
            self.image_contents_url = image_contents_url
        if inline_with_text is not None:
            self.inline_with_text = inline_with_text

    @property
    def path(self):
        """Gets the path of this DocxImage.  # noqa: E501

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :return: The path of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxImage.

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :param path: The path of this DocxImage.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def image_name(self):
        """Gets the image_name of this DocxImage.  # noqa: E501

        The Name of the image  # noqa: E501

        :return: The image_name of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """Sets the image_name of this DocxImage.

        The Name of the image  # noqa: E501

        :param image_name: The image_name of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_name = image_name

    @property
    def image_id(self):
        """Gets the image_id of this DocxImage.  # noqa: E501

        The Id of the image  # noqa: E501

        :return: The image_id of this DocxImage.  # noqa: E501
        :rtype: int
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this DocxImage.

        The Id of the image  # noqa: E501

        :param image_id: The image_id of this DocxImage.  # noqa: E501
        :type: int
        """

        self._image_id = image_id

    @property
    def image_description(self):
        """Gets the image_description of this DocxImage.  # noqa: E501

        The Description of the image  # noqa: E501

        :return: The image_description of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_description

    @image_description.setter
    def image_description(self, image_description):
        """Sets the image_description of this DocxImage.

        The Description of the image  # noqa: E501

        :param image_description: The image_description of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_description = image_description

    @property
    def image_width(self):
        """Gets the image_width of this DocxImage.  # noqa: E501

        Width of the image in EMUs (English Metric Units); set to 0 to default to page width and aspect-ratio based height  # noqa: E501

        :return: The image_width of this DocxImage.  # noqa: E501
        :rtype: int
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this DocxImage.

        Width of the image in EMUs (English Metric Units); set to 0 to default to page width and aspect-ratio based height  # noqa: E501

        :param image_width: The image_width of this DocxImage.  # noqa: E501
        :type: int
        """

        self._image_width = image_width

    @property
    def image_height(self):
        """Gets the image_height of this DocxImage.  # noqa: E501

        Height of the image in EMUs (English Metric Units); set to 0 to default to page width and aspect-ratio based height  # noqa: E501

        :return: The image_height of this DocxImage.  # noqa: E501
        :rtype: int
        """
        return self._image_height

    @image_height.setter
    def image_height(self, image_height):
        """Sets the image_height of this DocxImage.

        Height of the image in EMUs (English Metric Units); set to 0 to default to page width and aspect-ratio based height  # noqa: E501

        :param image_height: The image_height of this DocxImage.  # noqa: E501
        :type: int
        """

        self._image_height = image_height

    @property
    def x_offset(self):
        """Gets the x_offset of this DocxImage.  # noqa: E501

        X (horizontal) offset of the image  # noqa: E501

        :return: The x_offset of this DocxImage.  # noqa: E501
        :rtype: int
        """
        return self._x_offset

    @x_offset.setter
    def x_offset(self, x_offset):
        """Sets the x_offset of this DocxImage.

        X (horizontal) offset of the image  # noqa: E501

        :param x_offset: The x_offset of this DocxImage.  # noqa: E501
        :type: int
        """

        self._x_offset = x_offset

    @property
    def y_offset(self):
        """Gets the y_offset of this DocxImage.  # noqa: E501

        Y (vertical) offset of the image  # noqa: E501

        :return: The y_offset of this DocxImage.  # noqa: E501
        :rtype: int
        """
        return self._y_offset

    @y_offset.setter
    def y_offset(self, y_offset):
        """Sets the y_offset of this DocxImage.

        Y (vertical) offset of the image  # noqa: E501

        :param y_offset: The y_offset of this DocxImage.  # noqa: E501
        :type: int
        """

        self._y_offset = y_offset

    @property
    def image_data_embed_id(self):
        """Gets the image_data_embed_id of this DocxImage.  # noqa: E501

        Read-only; internal ID for the image contents  # noqa: E501

        :return: The image_data_embed_id of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_data_embed_id

    @image_data_embed_id.setter
    def image_data_embed_id(self, image_data_embed_id):
        """Sets the image_data_embed_id of this DocxImage.

        Read-only; internal ID for the image contents  # noqa: E501

        :param image_data_embed_id: The image_data_embed_id of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_data_embed_id = image_data_embed_id

    @property
    def image_data_content_type(self):
        """Gets the image_data_content_type of this DocxImage.  # noqa: E501

        Read-only; image data MIME content-type  # noqa: E501

        :return: The image_data_content_type of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_data_content_type

    @image_data_content_type.setter
    def image_data_content_type(self, image_data_content_type):
        """Sets the image_data_content_type of this DocxImage.

        Read-only; image data MIME content-type  # noqa: E501

        :param image_data_content_type: The image_data_content_type of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_data_content_type = image_data_content_type

    @property
    def image_internal_file_name(self):
        """Gets the image_internal_file_name of this DocxImage.  # noqa: E501

        Read-only; internal file name/path for the image  # noqa: E501

        :return: The image_internal_file_name of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_internal_file_name

    @image_internal_file_name.setter
    def image_internal_file_name(self, image_internal_file_name):
        """Sets the image_internal_file_name of this DocxImage.

        Read-only; internal file name/path for the image  # noqa: E501

        :param image_internal_file_name: The image_internal_file_name of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_internal_file_name = image_internal_file_name

    @property
    def image_contents_url(self):
        """Gets the image_contents_url of this DocxImage.  # noqa: E501

        URL to the image contents; file is stored in an in-memory cache and will be deleted.  Call Finish-Editing to get the contents.  # noqa: E501

        :return: The image_contents_url of this DocxImage.  # noqa: E501
        :rtype: str
        """
        return self._image_contents_url

    @image_contents_url.setter
    def image_contents_url(self, image_contents_url):
        """Sets the image_contents_url of this DocxImage.

        URL to the image contents; file is stored in an in-memory cache and will be deleted.  Call Finish-Editing to get the contents.  # noqa: E501

        :param image_contents_url: The image_contents_url of this DocxImage.  # noqa: E501
        :type: str
        """

        self._image_contents_url = image_contents_url

    @property
    def inline_with_text(self):
        """Gets the inline_with_text of this DocxImage.  # noqa: E501

        True if the image is inline with the text; false if it is floating  # noqa: E501

        :return: The inline_with_text of this DocxImage.  # noqa: E501
        :rtype: bool
        """
        return self._inline_with_text

    @inline_with_text.setter
    def inline_with_text(self, inline_with_text):
        """Sets the inline_with_text of this DocxImage.

        True if the image is inline with the text; false if it is floating  # noqa: E501

        :param inline_with_text: The inline_with_text of this DocxImage.  # noqa: E501
        :type: bool
        """

        self._inline_with_text = inline_with_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxImage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxImage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
